==> entity_usage_light-1.0.x-dev.tar.gz: entity_usage_light/src/Routing/RouteSubscriber.php <==
<?php

namespace Drupal\entity_usage_light\Routing;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Routing\RouteSubscriberBase;
use Drupal\Core\Routing\RoutingEvents;
use Symfony\Component\Routing\Route;
use Symfony\Component\Routing\RouteCollection;

/**
 * Subscriber for entity_usage_light routes.
 */
class RouteSubscriber extends RouteSubscriberBase {

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new RouteSubscriber object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  protected function alterRoutes(RouteCollection $collection) {
    foreach ($this->entityTypeManager->getDefinitions() as $entity_type_id => $entity_type) {
      if ($route = $this->getEntityUsageListRoute($entity_type)) {
        $collection->add("entity.$entity_type_id.usage_light", $route);
      }
    }
  }

  /**
   * Gets the entity load route.
   *
   * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
   *   The entity type.
   *
   * @return \Symfony\Component\Routing\Route|null
   *   The generated route, if available.
   */
  protected function getEntityUsageListRoute(EntityTypeInterface $entity_type) {
    if ($usage_light = $entity_type->getLinkTemplate('entity_usage_light')) {
      $entity_type_id = $entity_type->id();
      $route          = new Route($usage_light);
      $route
        ->addDefaults([
          '_controller' => '\Drupal\entity_usage_light\Controller\UsageController::list',
          '_title'      => 'Usage',
        ])
        ->addRequirements([
          '_permission' => 'access entity_usage_light information',
        ])
        ->setOption('_admin_route', TRUE)
        ->setOption('_usage_entity_type_id', $entity_type_id)
        ->setOption('parameters', [
          $entity_type_id => ['type' => 'entity:' . $entity_type_id],
        ]);

      return $route;
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    $events = parent::getSubscribedEvents();
    $events[RoutingEvents::ALTER] = ['onAlterRoutes', 100];
    return $events;
  }

}

==> entity_usage_light-2.0.x-dev.tar.gz: entity_usage_light/src/Routing/RouteSubscriber.php <==
<?php

namespace Drupal\entity_usage_light\Routing;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Routing\RouteSubscriberBase;
use Drupal\Core\Routing\RoutingEvents;
use Symfony\Component\Routing\Route;
use Symfony\Component\Routing\RouteCollection;

/**
 * Subscriber for entity_usage_light routes.
 */
class RouteSubscriber extends RouteSubscriberBase {

  /**
   * Constructs a new RouteSubscriber object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   */
  public function __construct(protected EntityTypeManagerInterface $entityTypeManager) {
  }

  /**
   * {@inheritdoc}
   */
  protected function alterRoutes(RouteCollection $collection): void {
    foreach ($this->entityTypeManager->getDefinitions() as $entity_type_id => $entity_type) {
      if ($route = $this->getEntityUsageListRoute($entity_type)) {
        $collection->add("entity.$entity_type_id.usage_light", $route);
      }
    }
  }

  /**
   * Gets the entity load route.
   *
   * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
   *   The entity type.
   *
   * @return \Symfony\Component\Routing\Route|null
   *   The generated route, if available.
   */
  protected function getEntityUsageListRoute(EntityTypeInterface $entity_type): ?Route {
    if ($usage_light = $entity_type->getLinkTemplate('entity_usage_light')) {
      $entity_type_id = $entity_type->id();
      $route          = new Route($usage_light);
      $route
        ->addDefaults([
          '_controller' => '\Drupal\entity_usage_light\Controller\UsageController::list',
          '_title'      => 'Usage',
        ])
        ->addRequirements([
          '_permission' => 'access entity_usage_light information',
        ])
        ->setOption('_admin_route', TRUE)
        ->setOption('_usage_entity_type_id', $entity_type_id)
        ->setOption('parameters', [
          $entity_type_id => ['type' => 'entity:' . $entity_type_id],
        ]);

      return $route;
    }
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    $events = parent::getSubscribedEvents();
    $events[RoutingEvents::ALTER] = ['onAlterRoutes', 100];
    return $events;
  }

}
